from django.contrib import admin
from comments.models import *

from . import models

# Register your models here.
from .models import Comment, Post,CommentPost



# Register your models here.

class PostAdmin(admin.ModelAdmin):
    model = models.Post
    list_display = ('excerpt',)

    def excerpt(self, obj):
        return obj.get_excerpt(5)


admin.site.register(Comment)

admin.site.register(models.CommentPost)
admin.site.register(models.Post,PostAdmin)
